| autocorPlot | R Documentation |
Plots current vs lagged residuals along with quadrants dividing these residuals about the value zero.
autocorPlot(fit, main = "Current vs Lagged residuals", ...)
fit |
output from the function 'lm()'. |
main |
the plot title. |
... |
extra parameters to be passed to the |
Plots current vs lagged residuals along with quadrants dividing these residuals about the value zero.
autocor.plot is deprecated and no longer exported.
Use autocorPlot() in new code.
data(airpass.df)
time = 1:144
airpass.fit = lm(passengers ~ time, data = airpass.df)
autocorPlot(airpass.fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.