| chalk.df | R Documentation |
These data involve 11 laboratories and 2 brands of chalk. The laboratories tested the density of the chalk. The main interest was whether the different laboratories yielded the same density for the two different types of chalk.
A data frame with 66 observations on 3 variables.
Numeric density of the chalk.
Integer laboratory identifier.
Factor giving the chalk brand tested (A, B).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.