extractTslmErrorSpec: Extract a tslm error specification

View source: R/tslm.R

extractTslmErrorSpecR Documentation

Extract a tslm error specification

Description

Extract and validate the supported autoregressive error term from parsed formula terms.

Usage

extractTslmErrorSpec(termsObject)

Arguments

termsObject

a terms object created from a 'tslm()' formula.

Value

'NULL' for independent errors, or a list describing the AR error structure.


s20x documentation built on July 1, 2026, 9:06 a.m.