getModelResidualFittedData: Get model residual and fitted-value data

View source: R/model-diagnostic-helpers.R

getModelResidualFittedDataR Documentation

Get model residual and fitted-value data

Description

Extract residuals and fitted values from a fitted model and validate that the two vectors are aligned for diagnostic plotting.

Usage

getModelResidualFittedData(object, residualType = NULL, context = "model")

Arguments

object

a fitted model object.

residualType

optional residual type passed to [stats::residuals()].

context

character description used in error messages.

Value

A list with 'fitted' and 'residuals' components.


s20x documentation built on July 1, 2026, 9:06 a.m.