getVersion: s20x package version number

View source: R/getVersion.R

getVersionR Documentation

s20x package version number

Description

Returns the version number of the s20x package. This is useful if a student has problems running commands and the maintainer needs to check the version number.

Usage

getVersion()

Examples


getVersion()


s20x documentation built on July 1, 2026, 9:06 a.m.