layout20x: Layout

View source: R/layout20x.R

layout20xR Documentation

Layout

Description

Allows a 'numRows' by 'numCols' matrix of plots to be displayed in a single plot. If the function is called with no arguments, then the plotting device layout will be reset to a single plot.

Usage

layout20x(numRows = 1, numCols = 1)

Arguments

numRows

Number of rows in the plot array.

numCols

Number of columns in the plot array.

Value

No return value.

Note

This is a legacy convenience wrapper retained for compatibility with older teaching material. New code can use par(mfrow = ...) directly.

Examples

data(course.df)
layout20x(1, 2)
stripchart(course.df$Exam)
boxplot(course.df$Exam)


s20x documentation built on July 1, 2026, 9:06 a.m.