makeTslmModelData: Make tslm model data

View source: R/tslm.R

makeTslmModelDataR Documentation

Make tslm model data

Description

Build the model frame used internally by 'tslm()'.

Usage

makeTslmModelData(meanFormula, data, timeName = NULL)

Arguments

meanFormula

formula used for the mean model after removing 'ar()'.

data

data frame or environment used to evaluate the model formula.

timeName

optional name of the time variable.

Value

A model frame containing the mean-model variables and, when supplied, the time variable.


s20x documentation built on July 1, 2026, 9:06 a.m.