| mergers.df | R Documentation |
A random selection of 38 consummated mergers from the USA, 1982, giving the number of days between the date the merger was announced and the date the merger became effective.
A data frame with 38 observations on 1 variable.
Numeric number of days between the merger announcement and the effective date.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.