| multipleComp | R Documentation |
Calculates and prints the estimate, multiple 95% confidence intervals, unadjusted, Tukey and Bonferroni p-values for all possible differences in means in a one-way ANOVA.
multipleComp(fit, conf.level = 0.95, FUN = identity)
fit |
Output from the command [lm()]. |
conf.level |
Confidence level for the confidence interval, expressed as a percentage. |
FUN |
Optional function to be applied to estimates and confidence intervals. Typically used for back-transformation operations. |
Returns a list of estimates, confidence intervals and p-values.
## computer data
data(computer.df)
fit = lm(score ~ factor(selfassess), data = computer.df)
multipleComp(fit)
## butterfat data
data("butterfat.df")
fit = lm(log(Butterfat) ~ Breed, data = butterfat.df)
multipleComp(fit, FUN = exp)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.