| nzalc.df | R Documentation |
Quarterly alcohol available for consumption in New Zealand from 1935 to 2021. The data give volumes of alcoholic beverages available for consumption, grouped into broad beverage categories.
A data frame with quarterly observations on 4 variables.
Integer Year.
Ordered factor giving the month at the end of the quarter.
Numeric volume available for consumption, in million litres.
Factor beverage category: 'Total beer', 'Total wine', or 'Total spirits'.
The 'month' variable gives the month ending the quarter. It should be treated in calendar order for plotting and summaries. For this quarterly data set the intended order is March, June, September, and December.
The 'category' variable has three levels:
Total beer available for consumption.
Total wine available for consumption.
Total spirits and spirit-based drinks available for consumption.
Stats NZ, Alcohol available for consumption: Year ended December 2021.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.