| nzarrivals.df | R Documentation |
Monthly international passenger arrivals to New Zealand from January 1921 to February 2026. Missing monthly observations, if present in the source series, are retained as rows with missing 'arrivals.count' values.
A data frame with monthly observations on 3 variables.
Integer year.
Factor month abbreviation with levels given by 'month.abb'.
Integer number of international passenger arrivals.
Stats NZ Infoshare, table ITM049AA, Total passenger movements (monthly), Arrivals, Actual Counts. Last updated 14 April 2026.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.