propslsd.new: LSD-Display Intervals

View source: R/propslsd.new.R

propslsd.newR Documentation

LSD-Display Intervals

Description

This function is called by rowdistr.

Usage

propslsd.new(crosstablist, conf.level = 0.95, arrowlength = 0.1)

Arguments

crosstablist

A list produced by crosstabs or a matrix containing a 2-way table of counts (without marginal totals).

conf.level

Confidence level of the intervals.

arrowlength

Length of the arrows.

Note

This is an internal legacy helper used by rowdistr(). It is not exported and should not be called directly by users.

See Also

crosstabs, rowdistr


s20x documentation built on July 1, 2026, 9:06 a.m.