requirePlottingPackage: Require an optional plotting package

View source: R/plotting-engine-helpers.R

requirePlottingPackageR Documentation

Require an optional plotting package

Description

Checks that an optional plotting package is installed and gives a consistent error message for optional plotting engines.

Usage

requirePlottingPackage(package, engine = "ggplot2")

Arguments

package

character name of the required optional package.

engine

character name of the plotting engine being used.

Value

Invisibly returns TRUE when the package is available.


s20x documentation built on July 1, 2026, 9:06 a.m.