Learn R Programming

s20x (version 3.1-38)

s0x: s20x: Functions for University of Auckland Course STATS 201/208 Data Analysis

Description

A set of functions used in teaching STATS 201/208 Data Analysis at the University of Auckland. The functions are designed to make parts of R more accessible to a large undergraduate population who are mostly not statistics majors.

Arguments

Author

Andrew Balemi, Dineika Chandra, James Curran, Brant Deppa, Mike Forster, Brendan McArdle, Chris Wild