s20x_ggplot2_base_theme: Build a base-like ggplot2 theme

View source: R/plotting-engine-helpers.R

s20x_ggplot2_base_themeR Documentation

Build a base-like ggplot2 theme

Description

Keeps optional ggplot2 diagnostic plots visually close to the original teaching plots by removing the default grey panel and grid.

Usage

s20x_ggplot2_base_theme()

Value

A ggplot2 theme object.


s20x documentation built on July 1, 2026, 9:06 a.m.