| seeds.df | R Documentation |
These data record the number of seeds (out of 100) that germinated when given different amounts of water. The seeds were either exposed to light or kept in the dark. Four identical boxes were used for each combination of water and light
A data frame with 48 observations on 3 variables.
Factor indicating whether the seeds were exposed to light (N = No, Y = Yes).
Integer amount of water, with higher levels corresponding to more water (1, 2, 3, 4, 5, 6).
Integer number of seeds that germinated, out of 100.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.