powered by
Calculates the skewness statistic of the data in 'x'. Values close to zero correspond to reasonably symmetric data, positive values of this measure indicate right-skewed data whereas negative values indicate left-skewness.
skewness(x)
vector containing the data.
Returns the value of the skewness.
# NOT RUN { ##Merger data: data(mergers.df) skewness(mergers.df$mergerdays) # }
Run the code above in your browser using DataLab