A list with the following components:
Dfdegrees of
freedom for regression, residual and total.
Sum of
Sqsum squares for regression, residual and total.
Mean
Sqmean squares for regression and residual.
F
valueF-statistic value.
Pr(F)The P-value assoicated
with each F-test.
Grand MeanThe overall mean of the
response variable.
Row EffectsThe main effects for the
first (row) factor.
Col EffectsThe main effects for
the second (column) factor.
Interaction EffectsThe
interaction effects if an interaction model has been fitted,
otherwise NULL.
resultsIf new = TRUE,
then this is a list with five components: table - the
ANOVA table, means the table of means from
model.tables, effects - the table of effects from
model.tables, and comparisons - the differences
in the means with standard errors, confidence bounds, and
P-values from TukeyHSD
.