| teach.df | R Documentation |
Data from an experiment to assess the impact of three different teaching methods on language ability. 30 students were randomly allocated into three groups, one for each method. The students' IQ before instruction and a language test score after instruction were recorded.
A data frame with 30 observations on 3 variables.
Numeric Language test score after instruction.
Numeric Student's IQ.
Factor Teaching method (1, 2, 3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.