| thyroid.df | R Documentation |
Data from an experiment to assess the effect of a new drug on the weight of the thyroid gland using 16 laboratory animals. The animals were randomly assigned into either a control group, or a treatment group, and each animal had its bodyweight recorded at the beginning of the experiment and its thyroid weight measured at the end of the experiment.
A data frame with 16 observations on 3 variables.
Numeric Weight of thyroid gland after 7 days (mg)
Numeric Animal body weight before experiment began (g)
Factor Animal's group (1 = control, 2 = drug)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.