Learn R Programming

s20x (version 3.1-29)

autocorPlot: Autocorrelation Plot

Description

Plots current vs lagged residuals along with quadrants dividing these residuals about the value zero.

Usage

autocorPlot(fit, main = "Current vs Lagged residuals", ...)

Arguments

fit

output from the function 'lm()'.

main

the plot title.

extra parameters to be passed to the plot function.

Value

Plots current vs lagged residuals along with quadrants dividing these residuals about the value zero.

Examples

Run this code
# NOT RUN {
data(airpass.df)
time = 1:144
airpass.fit = lm(passengers ~ time, data = airpass.df)
autocorPlot(airpass.fit)

# }

Run the code above in your browser using DataLab