| boxqq | R Documentation |
'boxqq()' is deprecated and is no longer exported. It draws boxplots and normal quantile-quantile plots of 'x' for each level of the grouping variable 'g'.
boxqq(formula, ...)
formula |
A symbolic specification of the form |
... |
Arguments to be passed to methods, such as graphical parameters
(see |
Returns the plot.
This is a legacy teaching helper retained for compatibility with older course material. New teaching material should prefer current diagnostic plotting workflows.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.