Learn R Programming

s20x (version 3.3.0)

boxqq: Deprecated box plots and normal quantile-quantile plots

Description

`boxqq()` is deprecated and is no longer exported. It draws boxplots and normal quantile-quantile plots of `x` for each level of the grouping variable `g`.

Usage

boxqq(formula, ...)

Value

Returns the plot.

Arguments

formula

A symbolic specification of the form x ~ g can be given, indicating the observations in the vector x are to be grouped according to the levels of the factor g. NA's are allowed in the data.

...

Arguments to be passed to methods, such as graphical parameters (see par).