Learn R Programming

s20x (version 3.3.0)

computer.df: Computer Questionnaire

Description

Data from a test to see if a questionnaire was properly designed. The questionnaire measures managers' technical knowledge of computers. The test has 19 managers complete the questionnaire as well as rate their own technical expertise.

Arguments

Format

A data frame with 19 observations on 2 variables.

score

Numeric questionnaire score.

selfassess

Ordered factor giving the self-assessed level of expertise (1 = low, 2 = medium, 3 = high).