| extractTslmErrorSpec | R Documentation |
Extract and validate the supported autoregressive error term from parsed formula terms.
extractTslmErrorSpec(termsObject)
termsObject |
a terms object created from a 'tslm()' formula. |
'NULL' for independent errors, or a list describing the AR error structure.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.