Learn R Programming

s20x (version 3.3.0)

extractTslmErrorSpec: Extract a tslm error specification

Description

Extract and validate the supported autoregressive error term from parsed formula terms.

Usage

extractTslmErrorSpec(termsObject)

Value

`NULL` for independent errors, or a list describing the AR error structure.

Arguments

termsObject

a terms object created from a `tslm()` formula.