View source: R/model-diagnostic-helpers.R
| getModelResidualFittedData | R Documentation |
Extract residuals and fitted values from a fitted model and validate that the two vectors are aligned for diagnostic plotting.
getModelResidualFittedData(object, residualType = NULL, context = "model")
object |
a fitted model object. |
residualType |
optional residual type passed to [stats::residuals()]. |
context |
character description used in error messages. |
A list with 'fitted' and 'residuals' components.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.