Learn R Programming

s20x (version 3.3.0)

getModelResidualFittedData: Get model residual and fitted-value data

Description

Extract residuals and fitted values from a fitted model and validate that the two vectors are aligned for diagnostic plotting.

Usage

getModelResidualFittedData(object, residualType = NULL, context = "model")

Value

A list with `fitted` and `residuals` components.

Arguments

object

a fitted model object.

residualType

optional residual type passed to [stats::residuals()].

context

character description used in error messages.