Extract residuals and fitted values from a fitted model and validate that the two vectors are aligned for diagnostic plotting.
getModelResidualFittedData(object, residualType = NULL, context = "model")A list with `fitted` and `residuals` components.
a fitted model object.
optional residual type passed to [stats::residuals()].
character description used in error messages.