Learn R Programming

s20x (version 3.3.0)

getVersion: s20x package version number

Description

Returns the version number of the s20x package. This is useful if a student has problems running commands and the maintainer needs to check the version number.

Usage

getVersion()

Arguments

Examples

Run this code

getVersion()

Run the code above in your browser using DataLab