powered by
Returns the version number of the s20x package. This is useful if a student has problems running commands and the maintainer needs to check the version number.
getVersion()
Run the code above in your browser using DataLab