| layout20x | R Documentation |
Allows a 'numRows' by 'numCols' matrix of plots to be displayed in a single plot. If the function is called with no arguments, then the plotting device layout will be reset to a single plot.
layout20x(numRows = 1, numCols = 1)
numRows |
Number of rows in the plot array. |
numCols |
Number of columns in the plot array. |
No return value.
This is a legacy convenience wrapper retained for compatibility with
older teaching material. New code can use par(mfrow = ...)
directly.
data(course.df)
layout20x(1, 2)
stripchart(course.df$Exam)
boxplot(course.df$Exam)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.