Learn R Programming

s20x (version 3.3.0)

layout20x: Layout

Description

Allows a `numRows` by `numCols` matrix of plots to be displayed in a single plot. If the function is called with no arguments, then the plotting device layout will be reset to a single plot.

Usage

layout20x(numRows = 1, numCols = 1)

Value

No return value.

Arguments

numRows

Number of rows in the plot array.

numCols

Number of columns in the plot array.

Examples

Run this code
data(course.df)
layout20x(1, 2)
stripchart(course.df$Exam)
boxplot(course.df$Exam)

Run the code above in your browser using DataLab