powered by
Allows a `numRows` by `numCols` matrix of plots to be displayed in a single plot. If the function is called with no arguments, then the plotting device layout will be reset to a single plot.
layout20x(numRows = 1, numCols = 1)
No return value.
Number of rows in the plot array.
Number of columns in the plot array.
data(course.df) layout20x(1, 2) stripchart(course.df$Exam) boxplot(course.df$Exam)
Run the code above in your browser using DataLab