powered by
Perform a Levene test for equal group variances in both one-way and two-way ANOVA. A table with the results is (normally) displayed.
levene.test(formula, data, digit = 5, show.table = TRUE)
a symbolic description of the model to be fitted: response ~ fac1 + fac2.
an optional data frame containing the variables in the model.
the number of decimal places to display.
If this argument is FALSE then the output will be suppressed
A list with the following elements:
degrees of freedom.
sum squares.
mean squares.
F-statistic value.
P-value.
crossFactors, anova.
crossFactors
anova
# NOT RUN { ## data(computer.df) levene.test(score ~ factor(selfassess), computer.df) # }
Run the code above in your browser using DataLab