| makeTslmModelData | R Documentation |
Build the model frame used internally by 'tslm()'.
makeTslmModelData(meanFormula, data, timeName = NULL)
meanFormula |
formula used for the mean model after removing 'ar()'. |
data |
data frame or environment used to evaluate the model formula. |
timeName |
optional name of the time variable. |
A model frame containing the mean-model variables and, when supplied, the time variable.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.