View source: R/plotting-engine-helpers.R
| matchPlottingEngine | R Documentation |
Applies the standard plotting engine argument matching used by exported plotting functions. Keeping this in one place makes engine-dispatch cleanup stages less repetitive without changing the accepted engine values.
matchPlottingEngine(engine, choices = c("base", "ggplot2"))
engine |
character plotting engine argument. |
choices |
character vector of accepted plotting engines. |
The matched plotting engine.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.