| modcheck | R Documentation |
'modcheck()' is deprecated and is no longer exported. It plots four model checking plots: residuals versus fitted values, a normal Q-Q plot, a histogram of residuals with a normal distribution superimposed, and a Cook's distance plot.
modcheck(x, ...)
x |
a vector of observations, or the residuals from fitting a linear model. Alternatively, a fitted |
... |
additional parameters. Included for future flexibility, but unsure how this might be used currently. |
Draws the selected model checking plots for teaching diagnostics. The function is called for its plotting side effects and does not provide a stable data return object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.