Learn R Programming

s20x (version 3.3.0)

nzarrivals.df: Monthly Arrivals to New Zealand

Description

Monthly international passenger arrivals to New Zealand from January 1921 to February 2026. Missing monthly observations, if present in the source series, are retained as rows with missing `arrivals.count` values.

Arguments

Format

A data frame with monthly observations on 3 variables.

year

Integer year.

month

Factor month abbreviation with levels given by `month.abb`.

arrivals.count

Integer number of international passenger arrivals.