Learn R Programming

s20x (version 3.1-29)

pairs20x: Pairwise Scatter Plots with Histograms and Correlations

Description

Plots pairwise scatter plots with histograms and correlations for the data frame.

Usage

pairs20x(x, na.rm = TRUE, ...)

Arguments

x

a data frame.

na.rm

if TRUE then only complete cases will be displayed

optional argumments which are passed to the generic pairs function.

Value

Returns the plots.

See Also

'pairs', 'panel.smooth', 'panel.cor', 'panel.hist'

Examples

Run this code
# NOT RUN {
##peruvian indians
data(peru.df)
pairs20x(peru.df)

# }

Run the code above in your browser using DataLab