powered by
Plots pairwise scatter plots with histograms and correlations for the data frame.
pairs20x(x, na.rm = TRUE, ...)
a data frame.
if TRUE then only complete cases will be displayed
optional argumments which are passed to the generic pairs function.
Returns the plots.
'pairs', 'panel.smooth', 'panel.cor', 'panel.hist'
# NOT RUN { ##peruvian indians data(peru.df) pairs20x(peru.df) # }
Run the code above in your browser using DataLab