| print.s20xNormcheck_ggplot2 | R Documentation |
Draws multiple ggplot2 normcheck plots side by side so the optional ggplot2
engine mirrors the base graphics layout for the default whichPlot = 1:2
case.
## S3 method for class 's20xNormcheck_ggplot2'
print(x, ...)
x |
an object returned by |
... |
additional arguments passed to |
Invisibly returns x.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.