Learn R Programming

s20x (version 3.3.0)

print.s20xNormcheck_ggplot2: Print ggplot2 normcheck plots

Description

Draws multiple ggplot2 normcheck plots side by side so the optional ggplot2 engine mirrors the base graphics layout for the default whichPlot = 1:2 case.

Usage

# S3 method for s20xNormcheck_ggplot2
print(x, ...)

Value

Invisibly returns x.

Arguments

x

an object returned by normcheck(..., engine = "ggplot2") when multiple plots are selected.

...

additional arguments passed to print.ggplot.