Draws multiple ggplot2 normcheck plots side by side so the optional ggplot2
engine mirrors the base graphics layout for the default whichPlot = 1:2
case.
# S3 method for s20xNormcheck_ggplot2
print(x, ...)Invisibly returns x.
an object returned by normcheck(..., engine = "ggplot2")
when multiple plots are selected.
additional arguments passed to print.ggplot.