| propslsd.new | R Documentation |
This function is called by rowdistr.
propslsd.new(crosstablist, conf.level = 0.95, arrowlength = 0.1)
crosstablist |
A list produced by |
conf.level |
Confidence level of the intervals. |
arrowlength |
Length of the arrows. |
This is an internal legacy helper used by rowdistr(). It is
not exported and should not be called directly by users.
crosstabs, rowdistr
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.