View source: R/plotting-engine-helpers.R
| requirePlottingPackage | R Documentation |
Checks that an optional plotting package is installed and gives a consistent error message for optional plotting engines.
requirePlottingPackage(package, engine = "ggplot2")
package |
character name of the required optional package. |
engine |
character name of the plotting engine being used. |
Invisibly returns TRUE when the package is available.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.