Learn R Programming

s20x (version 3.3.0)

requirePlottingPackage: Require an optional plotting package

Description

Checks that an optional plotting package is installed and gives a consistent error message for optional plotting engines.

Usage

requirePlottingPackage(package, engine = "ggplot2")

Value

Invisibly returns TRUE when the package is available.

Arguments

package

character name of the required optional package.

engine

character name of the plotting engine being used.