| residPlot | R Documentation |
Plots a scatter plot for the variables of the residuals and fitted values from the linear model, lmfit. A lowess smooth line for the underlying trend, as well as one standard deviation error bounds for the scatter about this trend, are added to this scatter plot. A test for a quadratic relationship between the residuals and the fitted values is also computed.
residPlot(lmfit, f = 0.5)
lmfit |
an |
f |
the smoother span. This gives the proportion of points in the plot which influence the smooth at each value. Larger values give more smoothness. |
Returns the plot.
This is a legacy diagnostic plotting helper retained for compatibility
with older teaching material. New code should usually prefer the current
diagnostic workflow used by modelcheck().
trendscatter
# Peruvian Indians data
data(peru.df)
fit = lm(BP ~ age + years + weight + height, data = peru.df)
residPlot(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.