View source: R/plotting-engine-helpers.R
| s20x_ggplot2_base_theme | R Documentation |
Keeps optional ggplot2 diagnostic plots visually close to the original teaching plots by removing the default grey panel and grid.
s20x_ggplot2_base_theme()
A ggplot2 theme object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.