Learn R Programming

s20x (version 3.3.0)

s20x_ggplot2_base_theme: Build a base-like ggplot2 theme

Description

Keeps optional ggplot2 diagnostic plots visually close to the original teaching plots by removing the default grey panel and grid.

Usage

s20x_ggplot2_base_theme()

Arguments

Value

A ggplot2 theme object.