`stripqq()` is deprecated and is no longer exported. It draws strip charts and normal quantile-quantile plots of `x` for each level of the grouping variable `g`.
stripqq(formula, ...)A symbolic specification of the form x ~ g can be
given, indicating the observations in the vector x are grouped
according to the levels of the factor g. NAs are allowed in
the data.
Optional arguments that are passed to the stripchart function.